@@ -1,7 +1,7 @@
 """
 Type annotations for workmail service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmail/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/type_defs/)
 
 Usage::
 
@@ -173,18 +173,19 @@ __all__ = (
 AccessControlRuleTypeDef = TypedDict(
     "AccessControlRuleTypeDef",
     {
-        "Name": NotRequired[str],
-        "Effect": NotRequired[AccessControlRuleEffectType],
-        "Description": NotRequired[str],
-        "IpRanges": NotRequired[List[str]],
-        "NotIpRanges": NotRequired[List[str]],
-        "Actions": NotRequired[List[str]],
-        "NotActions": NotRequired[List[str]],
-        "UserIds": NotRequired[List[str]],
-        "NotUserIds": NotRequired[List[str]],
-        "DateCreated": NotRequired[datetime],
-        "DateModified": NotRequired[datetime],
+        "Name": str,
+        "Effect": AccessControlRuleEffectType,
+        "Description": str,
+        "IpRanges": List[str],
+        "NotIpRanges": List[str],
+        "Actions": List[str],
+        "NotActions": List[str],
+        "UserIds": List[str],
+        "NotUserIds": List[str],
+        "DateCreated": datetime,
+        "DateModified": datetime,
     },
+    total=False,
 )
 
 AssociateDelegateToResourceRequestRequestTypeDef = TypedDict(
@@ -208,10 +209,11 @@ AssociateMemberToGroupRequestRequestTypeDef = TypedDict(
 BookingOptionsTypeDef = TypedDict(
     "BookingOptionsTypeDef",
     {
-        "AutoAcceptRequests": NotRequired[bool],
-        "AutoDeclineRecurringRequests": NotRequired[bool],
-        "AutoDeclineConflictingRequests": NotRequired[bool],
+        "AutoAcceptRequests": bool,
+        "AutoDeclineRecurringRequests": bool,
+        "AutoDeclineConflictingRequests": bool,
     },
+    total=False,
 )
 
 CancelMailboxExportJobRequestRequestTypeDef = TypedDict(
@@ -248,24 +250,38 @@ CreateGroupResponseTypeDef = TypedDict(
     },
 )
 
-CreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
-    "CreateMobileDeviceAccessRuleRequestRequestTypeDef",
+_RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "Name": str,
         "Effect": MobileDeviceAccessRuleEffectType,
-        "ClientToken": NotRequired[str],
-        "Description": NotRequired[str],
-        "DeviceTypes": NotRequired[Sequence[str]],
-        "NotDeviceTypes": NotRequired[Sequence[str]],
-        "DeviceModels": NotRequired[Sequence[str]],
-        "NotDeviceModels": NotRequired[Sequence[str]],
-        "DeviceOperatingSystems": NotRequired[Sequence[str]],
-        "NotDeviceOperatingSystems": NotRequired[Sequence[str]],
-        "DeviceUserAgents": NotRequired[Sequence[str]],
-        "NotDeviceUserAgents": NotRequired[Sequence[str]],
     },
 )
+_OptionalCreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateMobileDeviceAccessRuleRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Description": str,
+        "DeviceTypes": Sequence[str],
+        "NotDeviceTypes": Sequence[str],
+        "DeviceModels": Sequence[str],
+        "NotDeviceModels": Sequence[str],
+        "DeviceOperatingSystems": Sequence[str],
+        "NotDeviceOperatingSystems": Sequence[str],
+        "DeviceUserAgents": Sequence[str],
+        "NotDeviceUserAgents": Sequence[str],
+    },
+    total=False,
+)
+
+
+class CreateMobileDeviceAccessRuleRequestRequestTypeDef(
+    _RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef,
+    _OptionalCreateMobileDeviceAccessRuleRequestRequestTypeDef,
+):
+    pass
+
 
 CreateMobileDeviceAccessRuleResponseTypeDef = TypedDict(
     "CreateMobileDeviceAccessRuleResponseTypeDef",
@@ -275,17 +291,31 @@ CreateMobileDeviceAccessRuleResponseTypeDef = TypedDict(
     },
 )
 
-CreateOrganizationRequestRequestTypeDef = TypedDict(
-    "CreateOrganizationRequestRequestTypeDef",
+_RequiredCreateOrganizationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateOrganizationRequestRequestTypeDef",
     {
         "Alias": str,
-        "DirectoryId": NotRequired[str],
-        "ClientToken": NotRequired[str],
-        "Domains": NotRequired[Sequence["DomainTypeDef"]],
-        "KmsKeyArn": NotRequired[str],
-        "EnableInteroperability": NotRequired[bool],
     },
 )
+_OptionalCreateOrganizationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateOrganizationRequestRequestTypeDef",
+    {
+        "DirectoryId": str,
+        "ClientToken": str,
+        "Domains": Sequence["DomainTypeDef"],
+        "KmsKeyArn": str,
+        "EnableInteroperability": bool,
+    },
+    total=False,
+)
+
+
+class CreateOrganizationRequestRequestTypeDef(
+    _RequiredCreateOrganizationRequestRequestTypeDef,
+    _OptionalCreateOrganizationRequestRequestTypeDef,
+):
+    pass
+
 
 CreateOrganizationResponseTypeDef = TypedDict(
     "CreateOrganizationResponseTypeDef",
@@ -396,14 +426,28 @@ DeleteMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteOrganizationRequestRequestTypeDef = TypedDict(
-    "DeleteOrganizationRequestRequestTypeDef",
+_RequiredDeleteOrganizationRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteOrganizationRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "DeleteDirectory": bool,
-        "ClientToken": NotRequired[str],
     },
 )
+_OptionalDeleteOrganizationRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteOrganizationRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class DeleteOrganizationRequestRequestTypeDef(
+    _RequiredDeleteOrganizationRequestRequestTypeDef,
+    _OptionalDeleteOrganizationRequestRequestTypeDef,
+):
+    pass
+
 
 DeleteOrganizationResponseTypeDef = TypedDict(
     "DeleteOrganizationResponseTypeDef",
@@ -623,28 +667,43 @@ DisassociateMemberFromGroupRequestRequestTypeDef = TypedDict(
 DnsRecordTypeDef = TypedDict(
     "DnsRecordTypeDef",
     {
-        "Type": NotRequired[str],
-        "Hostname": NotRequired[str],
-        "Value": NotRequired[str],
+        "Type": str,
+        "Hostname": str,
+        "Value": str,
     },
+    total=False,
 )
 
 DomainTypeDef = TypedDict(
     "DomainTypeDef",
     {
-        "DomainName": NotRequired[str],
-        "HostedZoneId": NotRequired[str],
+        "DomainName": str,
+        "HostedZoneId": str,
     },
+    total=False,
 )
 
-FolderConfigurationTypeDef = TypedDict(
-    "FolderConfigurationTypeDef",
+_RequiredFolderConfigurationTypeDef = TypedDict(
+    "_RequiredFolderConfigurationTypeDef",
     {
         "Name": FolderNameType,
         "Action": RetentionActionType,
-        "Period": NotRequired[int],
     },
 )
+_OptionalFolderConfigurationTypeDef = TypedDict(
+    "_OptionalFolderConfigurationTypeDef",
+    {
+        "Period": int,
+    },
+    total=False,
+)
+
+
+class FolderConfigurationTypeDef(
+    _RequiredFolderConfigurationTypeDef, _OptionalFolderConfigurationTypeDef
+):
+    pass
+
 
 GetAccessControlEffectRequestRequestTypeDef = TypedDict(
     "GetAccessControlEffectRequestRequestTypeDef",
@@ -720,16 +779,30 @@ GetMailboxDetailsResponseTypeDef = TypedDict(
     },
 )
 
-GetMobileDeviceAccessEffectRequestRequestTypeDef = TypedDict(
-    "GetMobileDeviceAccessEffectRequestRequestTypeDef",
+_RequiredGetMobileDeviceAccessEffectRequestRequestTypeDef = TypedDict(
+    "_RequiredGetMobileDeviceAccessEffectRequestRequestTypeDef",
     {
         "OrganizationId": str,
-        "DeviceType": NotRequired[str],
-        "DeviceModel": NotRequired[str],
-        "DeviceOperatingSystem": NotRequired[str],
-        "DeviceUserAgent": NotRequired[str],
     },
 )
+_OptionalGetMobileDeviceAccessEffectRequestRequestTypeDef = TypedDict(
+    "_OptionalGetMobileDeviceAccessEffectRequestRequestTypeDef",
+    {
+        "DeviceType": str,
+        "DeviceModel": str,
+        "DeviceOperatingSystem": str,
+        "DeviceUserAgent": str,
+    },
+    total=False,
+)
+
+
+class GetMobileDeviceAccessEffectRequestRequestTypeDef(
+    _RequiredGetMobileDeviceAccessEffectRequestRequestTypeDef,
+    _OptionalGetMobileDeviceAccessEffectRequestRequestTypeDef,
+):
+    pass
+
 
 GetMobileDeviceAccessEffectResponseTypeDef = TypedDict(
     "GetMobileDeviceAccessEffectResponseTypeDef",
@@ -765,13 +838,14 @@ GetMobileDeviceAccessOverrideResponseTypeDef = TypedDict(
 GroupTypeDef = TypedDict(
     "GroupTypeDef",
     {
-        "Id": NotRequired[str],
-        "Email": NotRequired[str],
-        "Name": NotRequired[str],
-        "State": NotRequired[EntityStateType],
-        "EnabledDate": NotRequired[datetime],
-        "DisabledDate": NotRequired[datetime],
+        "Id": str,
+        "Email": str,
+        "Name": str,
+        "State": EntityStateType,
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
     },
+    total=False,
 )
 
 ListAccessControlRulesRequestRequestTypeDef = TypedDict(
@@ -789,24 +863,51 @@ ListAccessControlRulesResponseTypeDef = TypedDict(
     },
 )
 
-ListAliasesRequestListAliasesPaginateTypeDef = TypedDict(
-    "ListAliasesRequestListAliasesPaginateTypeDef",
+_RequiredListAliasesRequestListAliasesPaginateTypeDef = TypedDict(
+    "_RequiredListAliasesRequestListAliasesPaginateTypeDef",
     {
         "OrganizationId": str,
         "EntityId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListAliasesRequestListAliasesPaginateTypeDef = TypedDict(
+    "_OptionalListAliasesRequestListAliasesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListAliasesRequestRequestTypeDef = TypedDict(
-    "ListAliasesRequestRequestTypeDef",
+
+class ListAliasesRequestListAliasesPaginateTypeDef(
+    _RequiredListAliasesRequestListAliasesPaginateTypeDef,
+    _OptionalListAliasesRequestListAliasesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListAliasesRequestRequestTypeDef = TypedDict(
+    "_RequiredListAliasesRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "EntityId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListAliasesRequestRequestTypeDef = TypedDict(
+    "_OptionalListAliasesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListAliasesRequestRequestTypeDef(
+    _RequiredListAliasesRequestRequestTypeDef, _OptionalListAliasesRequestRequestTypeDef
+):
+    pass
+
 
 ListAliasesResponseTypeDef = TypedDict(
     "ListAliasesResponseTypeDef",
@@ -817,24 +918,51 @@ ListAliasesResponseTypeDef = TypedDict(
     },
 )
 
-ListGroupMembersRequestListGroupMembersPaginateTypeDef = TypedDict(
-    "ListGroupMembersRequestListGroupMembersPaginateTypeDef",
+_RequiredListGroupMembersRequestListGroupMembersPaginateTypeDef = TypedDict(
+    "_RequiredListGroupMembersRequestListGroupMembersPaginateTypeDef",
     {
         "OrganizationId": str,
         "GroupId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListGroupMembersRequestListGroupMembersPaginateTypeDef = TypedDict(
+    "_OptionalListGroupMembersRequestListGroupMembersPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListGroupMembersRequestRequestTypeDef = TypedDict(
-    "ListGroupMembersRequestRequestTypeDef",
+
+class ListGroupMembersRequestListGroupMembersPaginateTypeDef(
+    _RequiredListGroupMembersRequestListGroupMembersPaginateTypeDef,
+    _OptionalListGroupMembersRequestListGroupMembersPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListGroupMembersRequestRequestTypeDef = TypedDict(
+    "_RequiredListGroupMembersRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "GroupId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListGroupMembersRequestRequestTypeDef = TypedDict(
+    "_OptionalListGroupMembersRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListGroupMembersRequestRequestTypeDef(
+    _RequiredListGroupMembersRequestRequestTypeDef, _OptionalListGroupMembersRequestRequestTypeDef
+):
+    pass
+
 
 ListGroupMembersResponseTypeDef = TypedDict(
     "ListGroupMembersResponseTypeDef",
@@ -845,22 +973,49 @@ ListGroupMembersResponseTypeDef = TypedDict(
     },
 )
 
-ListGroupsRequestListGroupsPaginateTypeDef = TypedDict(
-    "ListGroupsRequestListGroupsPaginateTypeDef",
+_RequiredListGroupsRequestListGroupsPaginateTypeDef = TypedDict(
+    "_RequiredListGroupsRequestListGroupsPaginateTypeDef",
     {
         "OrganizationId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListGroupsRequestListGroupsPaginateTypeDef = TypedDict(
+    "_OptionalListGroupsRequestListGroupsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListGroupsRequestRequestTypeDef = TypedDict(
-    "ListGroupsRequestRequestTypeDef",
+
+class ListGroupsRequestListGroupsPaginateTypeDef(
+    _RequiredListGroupsRequestListGroupsPaginateTypeDef,
+    _OptionalListGroupsRequestListGroupsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListGroupsRequestRequestTypeDef = TypedDict(
+    "_RequiredListGroupsRequestRequestTypeDef",
     {
         "OrganizationId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListGroupsRequestRequestTypeDef = TypedDict(
+    "_OptionalListGroupsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListGroupsRequestRequestTypeDef(
+    _RequiredListGroupsRequestRequestTypeDef, _OptionalListGroupsRequestRequestTypeDef
+):
+    pass
+
 
 ListGroupsResponseTypeDef = TypedDict(
     "ListGroupsResponseTypeDef",
@@ -871,14 +1026,27 @@ ListGroupsResponseTypeDef = TypedDict(
     },
 )
 
-ListMailDomainsRequestRequestTypeDef = TypedDict(
-    "ListMailDomainsRequestRequestTypeDef",
+_RequiredListMailDomainsRequestRequestTypeDef = TypedDict(
+    "_RequiredListMailDomainsRequestRequestTypeDef",
     {
         "OrganizationId": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListMailDomainsRequestRequestTypeDef = TypedDict(
+    "_OptionalListMailDomainsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListMailDomainsRequestRequestTypeDef(
+    _RequiredListMailDomainsRequestRequestTypeDef, _OptionalListMailDomainsRequestRequestTypeDef
+):
+    pass
+
 
 ListMailDomainsResponseTypeDef = TypedDict(
     "ListMailDomainsResponseTypeDef",
@@ -889,14 +1057,28 @@ ListMailDomainsResponseTypeDef = TypedDict(
     },
 )
 
-ListMailboxExportJobsRequestRequestTypeDef = TypedDict(
-    "ListMailboxExportJobsRequestRequestTypeDef",
+_RequiredListMailboxExportJobsRequestRequestTypeDef = TypedDict(
+    "_RequiredListMailboxExportJobsRequestRequestTypeDef",
     {
         "OrganizationId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListMailboxExportJobsRequestRequestTypeDef = TypedDict(
+    "_OptionalListMailboxExportJobsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListMailboxExportJobsRequestRequestTypeDef(
+    _RequiredListMailboxExportJobsRequestRequestTypeDef,
+    _OptionalListMailboxExportJobsRequestRequestTypeDef,
+):
+    pass
+
 
 ListMailboxExportJobsResponseTypeDef = TypedDict(
     "ListMailboxExportJobsResponseTypeDef",
@@ -907,24 +1089,52 @@ ListMailboxExportJobsResponseTypeDef = TypedDict(
     },
 )
 
-ListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef = TypedDict(
-    "ListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef",
+_RequiredListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef = TypedDict(
+    "_RequiredListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef",
     {
         "OrganizationId": str,
         "EntityId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef = TypedDict(
+    "_OptionalListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListMailboxPermissionsRequestRequestTypeDef = TypedDict(
-    "ListMailboxPermissionsRequestRequestTypeDef",
+
+class ListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef(
+    _RequiredListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef,
+    _OptionalListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListMailboxPermissionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListMailboxPermissionsRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "EntityId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListMailboxPermissionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListMailboxPermissionsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListMailboxPermissionsRequestRequestTypeDef(
+    _RequiredListMailboxPermissionsRequestRequestTypeDef,
+    _OptionalListMailboxPermissionsRequestRequestTypeDef,
+):
+    pass
+
 
 ListMailboxPermissionsResponseTypeDef = TypedDict(
     "ListMailboxPermissionsResponseTypeDef",
@@ -935,16 +1145,30 @@ ListMailboxPermissionsResponseTypeDef = TypedDict(
     },
 )
 
-ListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
-    "ListMobileDeviceAccessOverridesRequestRequestTypeDef",
+_RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
+    "_RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef",
     {
         "OrganizationId": str,
-        "UserId": NotRequired[str],
-        "DeviceId": NotRequired[str],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
+    "_OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef",
+    {
+        "UserId": str,
+        "DeviceId": str,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListMobileDeviceAccessOverridesRequestRequestTypeDef(
+    _RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef,
+    _OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef,
+):
+    pass
+
 
 ListMobileDeviceAccessOverridesResponseTypeDef = TypedDict(
     "ListMobileDeviceAccessOverridesResponseTypeDef",
@@ -973,16 +1197,18 @@ ListMobileDeviceAccessRulesResponseTypeDef = TypedDict(
 ListOrganizationsRequestListOrganizationsPaginateTypeDef = TypedDict(
     "ListOrganizationsRequestListOrganizationsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListOrganizationsRequestRequestTypeDef = TypedDict(
     "ListOrganizationsRequestRequestTypeDef",
     {
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListOrganizationsResponseTypeDef = TypedDict(
@@ -994,24 +1220,52 @@ ListOrganizationsResponseTypeDef = TypedDict(
     },
 )
 
-ListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef = TypedDict(
-    "ListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef",
+_RequiredListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef = TypedDict(
+    "_RequiredListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef",
     {
         "OrganizationId": str,
         "ResourceId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef = TypedDict(
+    "_OptionalListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListResourceDelegatesRequestRequestTypeDef = TypedDict(
-    "ListResourceDelegatesRequestRequestTypeDef",
+
+class ListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef(
+    _RequiredListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef,
+    _OptionalListResourceDelegatesRequestListResourceDelegatesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListResourceDelegatesRequestRequestTypeDef = TypedDict(
+    "_RequiredListResourceDelegatesRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "ResourceId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListResourceDelegatesRequestRequestTypeDef = TypedDict(
+    "_OptionalListResourceDelegatesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListResourceDelegatesRequestRequestTypeDef(
+    _RequiredListResourceDelegatesRequestRequestTypeDef,
+    _OptionalListResourceDelegatesRequestRequestTypeDef,
+):
+    pass
+
 
 ListResourceDelegatesResponseTypeDef = TypedDict(
     "ListResourceDelegatesResponseTypeDef",
@@ -1022,22 +1276,49 @@ ListResourceDelegatesResponseTypeDef = TypedDict(
     },
 )
 
-ListResourcesRequestListResourcesPaginateTypeDef = TypedDict(
-    "ListResourcesRequestListResourcesPaginateTypeDef",
+_RequiredListResourcesRequestListResourcesPaginateTypeDef = TypedDict(
+    "_RequiredListResourcesRequestListResourcesPaginateTypeDef",
     {
         "OrganizationId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListResourcesRequestListResourcesPaginateTypeDef = TypedDict(
+    "_OptionalListResourcesRequestListResourcesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListResourcesRequestRequestTypeDef = TypedDict(
-    "ListResourcesRequestRequestTypeDef",
+
+class ListResourcesRequestListResourcesPaginateTypeDef(
+    _RequiredListResourcesRequestListResourcesPaginateTypeDef,
+    _OptionalListResourcesRequestListResourcesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListResourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListResourcesRequestRequestTypeDef",
     {
         "OrganizationId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListResourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListResourcesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListResourcesRequestRequestTypeDef(
+    _RequiredListResourcesRequestRequestTypeDef, _OptionalListResourcesRequestRequestTypeDef
+):
+    pass
+
 
 ListResourcesResponseTypeDef = TypedDict(
     "ListResourcesResponseTypeDef",
@@ -1063,22 +1344,49 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-ListUsersRequestListUsersPaginateTypeDef = TypedDict(
-    "ListUsersRequestListUsersPaginateTypeDef",
+_RequiredListUsersRequestListUsersPaginateTypeDef = TypedDict(
+    "_RequiredListUsersRequestListUsersPaginateTypeDef",
     {
         "OrganizationId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListUsersRequestListUsersPaginateTypeDef = TypedDict(
+    "_OptionalListUsersRequestListUsersPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListUsersRequestRequestTypeDef = TypedDict(
-    "ListUsersRequestRequestTypeDef",
+
+class ListUsersRequestListUsersPaginateTypeDef(
+    _RequiredListUsersRequestListUsersPaginateTypeDef,
+    _OptionalListUsersRequestListUsersPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListUsersRequestRequestTypeDef = TypedDict(
+    "_RequiredListUsersRequestRequestTypeDef",
     {
         "OrganizationId": str,
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListUsersRequestRequestTypeDef = TypedDict(
+    "_OptionalListUsersRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListUsersRequestRequestTypeDef(
+    _RequiredListUsersRequestRequestTypeDef, _OptionalListUsersRequestRequestTypeDef
+):
+    pass
+
 
 ListUsersResponseTypeDef = TypedDict(
     "ListUsersResponseTypeDef",
@@ -1092,96 +1400,104 @@ ListUsersResponseTypeDef = TypedDict(
 MailDomainSummaryTypeDef = TypedDict(
     "MailDomainSummaryTypeDef",
     {
-        "DomainName": NotRequired[str],
-        "DefaultDomain": NotRequired[bool],
+        "DomainName": str,
+        "DefaultDomain": bool,
     },
+    total=False,
 )
 
 MailboxExportJobTypeDef = TypedDict(
     "MailboxExportJobTypeDef",
     {
-        "JobId": NotRequired[str],
-        "EntityId": NotRequired[str],
-        "Description": NotRequired[str],
-        "S3BucketName": NotRequired[str],
-        "S3Path": NotRequired[str],
-        "EstimatedProgress": NotRequired[int],
-        "State": NotRequired[MailboxExportJobStateType],
-        "StartTime": NotRequired[datetime],
-        "EndTime": NotRequired[datetime],
+        "JobId": str,
+        "EntityId": str,
+        "Description": str,
+        "S3BucketName": str,
+        "S3Path": str,
+        "EstimatedProgress": int,
+        "State": MailboxExportJobStateType,
+        "StartTime": datetime,
+        "EndTime": datetime,
     },
+    total=False,
 )
 
 MemberTypeDef = TypedDict(
     "MemberTypeDef",
     {
-        "Id": NotRequired[str],
-        "Name": NotRequired[str],
-        "Type": NotRequired[MemberTypeType],
-        "State": NotRequired[EntityStateType],
-        "EnabledDate": NotRequired[datetime],
-        "DisabledDate": NotRequired[datetime],
+        "Id": str,
+        "Name": str,
+        "Type": MemberTypeType,
+        "State": EntityStateType,
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
     },
+    total=False,
 )
 
 MobileDeviceAccessMatchedRuleTypeDef = TypedDict(
     "MobileDeviceAccessMatchedRuleTypeDef",
     {
-        "MobileDeviceAccessRuleId": NotRequired[str],
-        "Name": NotRequired[str],
+        "MobileDeviceAccessRuleId": str,
+        "Name": str,
     },
+    total=False,
 )
 
 MobileDeviceAccessOverrideTypeDef = TypedDict(
     "MobileDeviceAccessOverrideTypeDef",
     {
-        "UserId": NotRequired[str],
-        "DeviceId": NotRequired[str],
-        "Effect": NotRequired[MobileDeviceAccessRuleEffectType],
-        "Description": NotRequired[str],
-        "DateCreated": NotRequired[datetime],
-        "DateModified": NotRequired[datetime],
+        "UserId": str,
+        "DeviceId": str,
+        "Effect": MobileDeviceAccessRuleEffectType,
+        "Description": str,
+        "DateCreated": datetime,
+        "DateModified": datetime,
     },
+    total=False,
 )
 
 MobileDeviceAccessRuleTypeDef = TypedDict(
     "MobileDeviceAccessRuleTypeDef",
     {
-        "MobileDeviceAccessRuleId": NotRequired[str],
-        "Name": NotRequired[str],
-        "Description": NotRequired[str],
-        "Effect": NotRequired[MobileDeviceAccessRuleEffectType],
-        "DeviceTypes": NotRequired[List[str]],
-        "NotDeviceTypes": NotRequired[List[str]],
-        "DeviceModels": NotRequired[List[str]],
-        "NotDeviceModels": NotRequired[List[str]],
-        "DeviceOperatingSystems": NotRequired[List[str]],
-        "NotDeviceOperatingSystems": NotRequired[List[str]],
-        "DeviceUserAgents": NotRequired[List[str]],
-        "NotDeviceUserAgents": NotRequired[List[str]],
-        "DateCreated": NotRequired[datetime],
-        "DateModified": NotRequired[datetime],
+        "MobileDeviceAccessRuleId": str,
+        "Name": str,
+        "Description": str,
+        "Effect": MobileDeviceAccessRuleEffectType,
+        "DeviceTypes": List[str],
+        "NotDeviceTypes": List[str],
+        "DeviceModels": List[str],
+        "NotDeviceModels": List[str],
+        "DeviceOperatingSystems": List[str],
+        "NotDeviceOperatingSystems": List[str],
+        "DeviceUserAgents": List[str],
+        "NotDeviceUserAgents": List[str],
+        "DateCreated": datetime,
+        "DateModified": datetime,
     },
+    total=False,
 )
 
 OrganizationSummaryTypeDef = TypedDict(
     "OrganizationSummaryTypeDef",
     {
-        "OrganizationId": NotRequired[str],
-        "Alias": NotRequired[str],
-        "DefaultMailDomain": NotRequired[str],
-        "ErrorMessage": NotRequired[str],
-        "State": NotRequired[str],
+        "OrganizationId": str,
+        "Alias": str,
+        "DefaultMailDomain": str,
+        "ErrorMessage": str,
+        "State": str,
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PermissionTypeDef = TypedDict(
@@ -1193,21 +1509,35 @@ PermissionTypeDef = TypedDict(
     },
 )
 
-PutAccessControlRuleRequestRequestTypeDef = TypedDict(
-    "PutAccessControlRuleRequestRequestTypeDef",
+_RequiredPutAccessControlRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredPutAccessControlRuleRequestRequestTypeDef",
     {
         "Name": str,
         "Effect": AccessControlRuleEffectType,
         "Description": str,
         "OrganizationId": str,
-        "IpRanges": NotRequired[Sequence[str]],
-        "NotIpRanges": NotRequired[Sequence[str]],
-        "Actions": NotRequired[Sequence[str]],
-        "NotActions": NotRequired[Sequence[str]],
-        "UserIds": NotRequired[Sequence[str]],
-        "NotUserIds": NotRequired[Sequence[str]],
     },
 )
+_OptionalPutAccessControlRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalPutAccessControlRuleRequestRequestTypeDef",
+    {
+        "IpRanges": Sequence[str],
+        "NotIpRanges": Sequence[str],
+        "Actions": Sequence[str],
+        "NotActions": Sequence[str],
+        "UserIds": Sequence[str],
+        "NotUserIds": Sequence[str],
+    },
+    total=False,
+)
+
+
+class PutAccessControlRuleRequestRequestTypeDef(
+    _RequiredPutAccessControlRuleRequestRequestTypeDef,
+    _OptionalPutAccessControlRuleRequestRequestTypeDef,
+):
+    pass
+
 
 PutEmailMonitoringConfigurationRequestRequestTypeDef = TypedDict(
     "PutEmailMonitoringConfigurationRequestRequestTypeDef",
@@ -1236,36 +1566,78 @@ PutMailboxPermissionsRequestRequestTypeDef = TypedDict(
     },
 )
 
-PutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
-    "PutMobileDeviceAccessOverrideRequestRequestTypeDef",
+_RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
+    "_RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "UserId": str,
         "DeviceId": str,
         "Effect": MobileDeviceAccessRuleEffectType,
-        "Description": NotRequired[str],
     },
 )
+_OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
+    "_OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
 
-PutRetentionPolicyRequestRequestTypeDef = TypedDict(
-    "PutRetentionPolicyRequestRequestTypeDef",
+
+class PutMobileDeviceAccessOverrideRequestRequestTypeDef(
+    _RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef,
+    _OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredPutRetentionPolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredPutRetentionPolicyRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "Name": str,
         "FolderConfigurations": Sequence["FolderConfigurationTypeDef"],
-        "Id": NotRequired[str],
-        "Description": NotRequired[str],
     },
 )
+_OptionalPutRetentionPolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalPutRetentionPolicyRequestRequestTypeDef",
+    {
+        "Id": str,
+        "Description": str,
+    },
+    total=False,
+)
 
-RegisterMailDomainRequestRequestTypeDef = TypedDict(
-    "RegisterMailDomainRequestRequestTypeDef",
+
+class PutRetentionPolicyRequestRequestTypeDef(
+    _RequiredPutRetentionPolicyRequestRequestTypeDef,
+    _OptionalPutRetentionPolicyRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredRegisterMailDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredRegisterMailDomainRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "DomainName": str,
-        "ClientToken": NotRequired[str],
     },
 )
+_OptionalRegisterMailDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalRegisterMailDomainRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class RegisterMailDomainRequestRequestTypeDef(
+    _RequiredRegisterMailDomainRequestRequestTypeDef,
+    _OptionalRegisterMailDomainRequestRequestTypeDef,
+):
+    pass
+
 
 RegisterToWorkMailRequestRequestTypeDef = TypedDict(
     "RegisterToWorkMailRequestRequestTypeDef",
@@ -1288,14 +1660,15 @@ ResetPasswordRequestRequestTypeDef = TypedDict(
 ResourceTypeDef = TypedDict(
     "ResourceTypeDef",
     {
-        "Id": NotRequired[str],
-        "Email": NotRequired[str],
-        "Name": NotRequired[str],
-        "Type": NotRequired[ResourceTypeType],
-        "State": NotRequired[EntityStateType],
-        "EnabledDate": NotRequired[datetime],
-        "DisabledDate": NotRequired[datetime],
+        "Id": str,
+        "Email": str,
+        "Name": str,
+        "Type": ResourceTypeType,
+        "State": EntityStateType,
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -1309,8 +1682,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-StartMailboxExportJobRequestRequestTypeDef = TypedDict(
-    "StartMailboxExportJobRequestRequestTypeDef",
+_RequiredStartMailboxExportJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartMailboxExportJobRequestRequestTypeDef",
     {
         "ClientToken": str,
         "OrganizationId": str,
@@ -1319,9 +1692,23 @@ StartMailboxExportJobRequestRequestTypeDef = TypedDict(
         "KmsKeyArn": str,
         "S3BucketName": str,
         "S3Prefix": str,
-        "Description": NotRequired[str],
     },
 )
+_OptionalStartMailboxExportJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartMailboxExportJobRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class StartMailboxExportJobRequestRequestTypeDef(
+    _RequiredStartMailboxExportJobRequestRequestTypeDef,
+    _OptionalStartMailboxExportJobRequestRequestTypeDef,
+):
+    pass
+
 
 StartMailboxExportJobResponseTypeDef = TypedDict(
     "StartMailboxExportJobResponseTypeDef",
@@ -1372,24 +1759,38 @@ UpdateMailboxQuotaRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
-    "UpdateMobileDeviceAccessRuleRequestRequestTypeDef",
+_RequiredUpdateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateMobileDeviceAccessRuleRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "MobileDeviceAccessRuleId": str,
         "Name": str,
         "Effect": MobileDeviceAccessRuleEffectType,
-        "Description": NotRequired[str],
-        "DeviceTypes": NotRequired[Sequence[str]],
-        "NotDeviceTypes": NotRequired[Sequence[str]],
-        "DeviceModels": NotRequired[Sequence[str]],
-        "NotDeviceModels": NotRequired[Sequence[str]],
-        "DeviceOperatingSystems": NotRequired[Sequence[str]],
-        "NotDeviceOperatingSystems": NotRequired[Sequence[str]],
-        "DeviceUserAgents": NotRequired[Sequence[str]],
-        "NotDeviceUserAgents": NotRequired[Sequence[str]],
     },
 )
+_OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef",
+    {
+        "Description": str,
+        "DeviceTypes": Sequence[str],
+        "NotDeviceTypes": Sequence[str],
+        "DeviceModels": Sequence[str],
+        "NotDeviceModels": Sequence[str],
+        "DeviceOperatingSystems": Sequence[str],
+        "NotDeviceOperatingSystems": Sequence[str],
+        "DeviceUserAgents": Sequence[str],
+        "NotDeviceUserAgents": Sequence[str],
+    },
+    total=False,
+)
+
+
+class UpdateMobileDeviceAccessRuleRequestRequestTypeDef(
+    _RequiredUpdateMobileDeviceAccessRuleRequestRequestTypeDef,
+    _OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef,
+):
+    pass
+
 
 UpdatePrimaryEmailAddressRequestRequestTypeDef = TypedDict(
     "UpdatePrimaryEmailAddressRequestRequestTypeDef",
@@ -1400,26 +1801,40 @@ UpdatePrimaryEmailAddressRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateResourceRequestRequestTypeDef = TypedDict(
-    "UpdateResourceRequestRequestTypeDef",
+_RequiredUpdateResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateResourceRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "ResourceId": str,
-        "Name": NotRequired[str],
-        "BookingOptions": NotRequired["BookingOptionsTypeDef"],
     },
 )
+_OptionalUpdateResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateResourceRequestRequestTypeDef",
+    {
+        "Name": str,
+        "BookingOptions": "BookingOptionsTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateResourceRequestRequestTypeDef(
+    _RequiredUpdateResourceRequestRequestTypeDef, _OptionalUpdateResourceRequestRequestTypeDef
+):
+    pass
+
 
 UserTypeDef = TypedDict(
     "UserTypeDef",
     {
-        "Id": NotRequired[str],
-        "Email": NotRequired[str],
-        "Name": NotRequired[str],
-        "DisplayName": NotRequired[str],
-        "State": NotRequired[EntityStateType],
-        "UserRole": NotRequired[UserRoleType],
-        "EnabledDate": NotRequired[datetime],
-        "DisabledDate": NotRequired[datetime],
+        "Id": str,
+        "Email": str,
+        "Name": str,
+        "DisplayName": str,
+        "State": EntityStateType,
+        "UserRole": UserRoleType,
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
     },
+    total=False,
 )
